<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>FeatherNotes::AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="175"/>
        <source>License</source>
        <translation>Licencija</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::ColorLabel</name>
    <message>
        <location filename="../../colorLabel.cpp" line="31"/>
        <source>Click to change color.</source>
        <translation>Spustelėkite norėdami pakeisti spalvą.</translation>
    </message>
    <message>
        <location filename="../../colorLabel.cpp" line="53"/>
        <source>Select Color</source>
        <translation>Pasirinkti spalvą</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::FN</name>
    <message>
        <location filename="../../fn.ui" line="14"/>
        <source>FeatherNotes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="65"/>
        <source>Next (F3)</source>
        <translation>Kitas (F3)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="68"/>
        <source>F3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="81"/>
        <source>Previous (F4)</source>
        <translation>Ankstesnis (F4)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="84"/>
        <source>F4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="100"/>
        <source>Search...</source>
        <translation>Ieškoti...</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="115"/>
        <source>Search only in names (Ctrl+Shift+F7)</source>
        <translation>Ieškoti tik pavadinimuose (Ctrl+Shift+F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="118"/>
        <source>Ctrl+Shift+F7</source>
        <translation>Ctrl+Shift+F7</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="128"/>
        <source>Search only in tags (Shift+F7)</source>
        <translation>Ieškoti tik žymėse (Shift+F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="131"/>
        <source>Shift+F7</source>
        <translation>Shift+F7</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="144"/>
        <source>Search in all nodes (F7)</source>
        <translation>Ieškoti visuose mazguose (F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="147"/>
        <source>F7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="186"/>
        <source>Whole Word (F6)</source>
        <translation>Visas žodis (F6)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="189"/>
        <source>Whole Word</source>
        <translation>Visas žodis</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="192"/>
        <source>F6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="167"/>
        <source>Match Case (F5)</source>
        <translation>Skirti raidžių dydį (F5)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="170"/>
        <source>Match Case</source>
        <translation>Skirti raidžių dydį</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="173"/>
        <source>F5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="219"/>
        <source>&amp;File</source>
        <translation>&amp;Failas</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="223"/>
        <source>Recenl&amp;y Opened</source>
        <translation>Paskiaus&amp;iai atverti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="245"/>
        <source>&amp;Edit</source>
        <translation>&amp;Taisa</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="264"/>
        <source>For&amp;mat</source>
        <translation>For&amp;matavimas</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="296"/>
        <source>&amp;Tree</source>
        <translation>&amp;Medis</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="320"/>
        <source>&amp;Options</source>
        <translation>&amp;Parinktys</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="334"/>
        <source>&amp;Search</source>
        <translation>Paieš&amp;ka</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="341"/>
        <location filename="../../fn.ui" line="987"/>
        <source>&amp;Help</source>
        <translation>Ž&amp;inynas</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="436"/>
        <source>Find:</source>
        <translation>Rasti:</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="443"/>
        <source>Replace with:</source>
        <translation>Kuo pakeisti:</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="456"/>
        <source>To be replaced</source>
        <translation>Bus pakeista</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="469"/>
        <source>Replacing text</source>
        <translation>Tekstas, kuriuo keičiama</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="479"/>
        <source>Previous (F9)</source>
        <translation>Ankstesnis (F9)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="482"/>
        <source>F9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="495"/>
        <source>Next (F8)</source>
        <translation>Kitas (F8)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="498"/>
        <source>F8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="511"/>
        <source>Replace all (F10)</source>
        <translation>Pakeisti visus (F10)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="514"/>
        <source>F10</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="531"/>
        <source>&amp;Save</source>
        <translation>Į&amp;rašyti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="534"/>
        <location filename="../../fn.cpp" line="1031"/>
        <source>Save</source>
        <translation>Įrašyti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="537"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="542"/>
        <location filename="../../fn.cpp" line="691"/>
        <source>&amp;Open</source>
        <translation>A&amp;tverti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="545"/>
        <source>Open a file</source>
        <translation>Atverti failą</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="548"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="556"/>
        <source>&amp;Undo</source>
        <translation>A&amp;tšaukti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="559"/>
        <source>Undo</source>
        <translation>Atšaukti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="562"/>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="570"/>
        <source>&amp;Redo</source>
        <translation>&amp;Grąžinti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="573"/>
        <source>Redo</source>
        <translation>Grąžinti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="576"/>
        <source>Ctrl+Shift+Z</source>
        <translation>Ctrl+Shift+Z</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="584"/>
        <source>&amp;Find</source>
        <translation>&amp;Rasti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="587"/>
        <source>Show/hide searchbar</source>
        <translation>Rodyti/slėpti paieškos juostą</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="590"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="598"/>
        <source>&amp;Clear All Formats</source>
        <translation>&amp;Išvalyti visą formatavimą</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="601"/>
        <source>Clear all formats</source>
        <translation>Išvalyti visą formatavimą</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="604"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="615"/>
        <source>&amp;Bold</source>
        <translation>&amp;Pusjuodis</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="618"/>
        <source>Bold</source>
        <translation>Pusjuodis</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="621"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="632"/>
        <source>&amp;Italic</source>
        <translation>&amp;Kursyvas</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="635"/>
        <source>Italic</source>
        <translation>Kursyvas</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="638"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="649"/>
        <source>&amp;Underline</source>
        <translation>Pa&amp;brauktas</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="652"/>
        <source>Underline</source>
        <translation>Pabrauktas</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="655"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="666"/>
        <source>&amp;Strike Through</source>
        <translation>Pe&amp;rbrauktas</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="669"/>
        <source>Strike through</source>
        <translation>Perbrauktas</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="672"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="680"/>
        <source>Te&amp;xt Color</source>
        <translation>Te&amp;ksto spalva</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="683"/>
        <source>Text color</source>
        <translation>Teksto spalva</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="686"/>
        <source>Alt+Shift+T</source>
        <translation>Alt+Shift+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="694"/>
        <source>Back&amp;ground Color</source>
        <translation>&amp;Fono spalva</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="697"/>
        <source>Background color</source>
        <translation>Fono spalva</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="700"/>
        <source>Alt+Shift+B</source>
        <translation>Alt+Shift+B</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="705"/>
        <source>Options</source>
        <translation>Parinktys</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="710"/>
        <location filename="../../fn.cpp" line="690"/>
        <source>&amp;New Note</source>
        <translation>&amp;Nauji užrašai</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="713"/>
        <source>Ctrl+Alt+Shift+N</source>
        <translation>Ctrl+Alt+Shift+N</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="721"/>
        <source>Save &amp;As</source>
        <translation>Įrašyti k&amp;aip</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="724"/>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="732"/>
        <source>&amp;Print</source>
        <translation>S&amp;pausdinti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="735"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="743"/>
        <source>P&amp;rint with Sub-Nodes</source>
        <translation>Spaus&amp;dinti su pomazgiais</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="751"/>
        <source>Set Pass&amp;word</source>
        <translation>Nustatyti s&amp;laptažodį</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="756"/>
        <location filename="../../fn.cpp" line="693"/>
        <source>&amp;Quit</source>
        <translation>&amp;Išeiti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="759"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="767"/>
        <source>&amp;Cut</source>
        <translation>Iš&amp;kirpti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="770"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="778"/>
        <source>C&amp;opy</source>
        <translation>K&amp;opijuoti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="781"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="789"/>
        <source>&amp;Paste</source>
        <translation>Į&amp;dėti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="792"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="800"/>
        <source>&amp;Delete</source>
        <translation>Iš&amp;trinti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="808"/>
        <source>&amp;Select All</source>
        <translation>Ž&amp;ymėti viską</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="811"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="819"/>
        <source>E&amp;mbed Image</source>
        <translation>Įtaisyti pa&amp;veikslą</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="822"/>
        <location filename="../../fn.cpp" line="4378"/>
        <source>Embed Image</source>
        <translation>Įtaisyti paveikslą</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="825"/>
        <source>Ctrl+Alt+Shift+I</source>
        <translation>Ctrl+Alt+Shift+I</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="833"/>
        <source>E&amp;xpand All</source>
        <translation>Viską išsk&amp;leisti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="836"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Žemyn</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="844"/>
        <source>Collap&amp;se All</source>
        <translation>Viską s&amp;uskleisti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="847"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Aukštyn</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="855"/>
        <source>&amp;Append Sibling</source>
        <translation>Pridėti &amp;giminingą žemiau</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="858"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="866"/>
        <source>Append &amp;Child</source>
        <translation>Pridėti pa&amp;valdųjį</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="869"/>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="877"/>
        <source>&amp;Delete Node</source>
        <translation>&amp;Ištrinti mazgą</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="880"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="888"/>
        <source>Move &amp;Up</source>
        <translation>Pa&amp;kelti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="891"/>
        <source>Alt+Up</source>
        <translation>Alt+Aukštyn</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="899"/>
        <source>Move Do&amp;wn</source>
        <translation>N&amp;uleisti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="902"/>
        <source>Alt+Down</source>
        <translation>Alt+Žemyn</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="910"/>
        <source>Re&amp;name Node</source>
        <translation>Pervadi&amp;nti mazgą</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="913"/>
        <source>Ctrl+Shift+R</source>
        <translation>Ctrl+Shift+R</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="918"/>
        <source>Tree Pr&amp;operties</source>
        <translation>Medžio sa&amp;vybės</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="921"/>
        <source>Ctrl+Shift+D</source>
        <translation>Ctrl+Shift+D</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="929"/>
        <source>Document &amp;Font</source>
        <translation>Dokumento šri&amp;ftas</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="943"/>
        <source>&amp;Wrap Lines</source>
        <translation>Skai&amp;dyti eilutes</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="946"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="960"/>
        <source>&amp;Auto-Indentation</source>
        <translation>&amp;Automatinė įtrauka</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="963"/>
        <source>Ctrl+Shift+I</source>
        <translation>Ctrl+Shift+I</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="968"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Nuostatos</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="971"/>
        <source>Ctrl+Shift+P</source>
        <translation>Ctrl+Shift+P</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="979"/>
        <source>Find and &amp;Replace</source>
        <translation>Rasti ir pa&amp;keisti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="982"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="990"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="995"/>
        <source>&amp;About</source>
        <translation>&amp;Apie</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1003"/>
        <source>Pr&amp;int All Nodes</source>
        <translation>Spausd&amp;inti visus mazgus</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1014"/>
        <source>Superscrip&amp;t</source>
        <translation>Viršu&amp;tinis indeksas</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1017"/>
        <source>Superscript</source>
        <translation>Viršutinis indeksas</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1020"/>
        <source>Alt+Shift+U</source>
        <translation>Alt+Shift+U</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1031"/>
        <source>Subscri&amp;pt</source>
        <translation>A&amp;patinis indeksas</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1034"/>
        <source>Subscript</source>
        <translation>Apatinis indeksas</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1037"/>
        <source>Alt+Shift+S</source>
        <translation>Alt+Shift+S</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1048"/>
        <source>C&amp;enter</source>
        <translation>C&amp;entre</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1051"/>
        <source>Align center</source>
        <translation>Lygiuoti centre</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1054"/>
        <source>Alt+Shift+Down</source>
        <translation>Alt+Shift+Žemyn</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1065"/>
        <location filename="../../fn.cpp" line="2176"/>
        <source>&amp;Right</source>
        <translation>&amp;Dešinėje</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1068"/>
        <source>Align right</source>
        <translation>Lygiuoti dešinėje</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1071"/>
        <source>Alt+Shift+Right</source>
        <translation>Alt+Shift+Dešinėn</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1082"/>
        <location filename="../../fn.cpp" line="2170"/>
        <source>&amp;Left</source>
        <translation>&amp;Kairėje</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1085"/>
        <source>Align left</source>
        <translation>Lygiuoti kairėje</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1088"/>
        <source>Alt+Shift+Left</source>
        <translation>Alt+Shift+Kairėn</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1099"/>
        <source>&amp;Justify</source>
        <translation>&amp;Abipusė lygiuotė</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1102"/>
        <source>Justify</source>
        <translation>Abipusė lygiuotė</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1105"/>
        <source>Alt+Shift+Up</source>
        <translation>Alt+Shift+Aukštyn</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1113"/>
        <source>&amp;Prepend Sibling</source>
        <translation>&amp;Pridėti giminingą aukščiau</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1116"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1124"/>
        <source>Move &amp;Left</source>
        <translation>Perkelti ka&amp;irėn</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1127"/>
        <source>Alt+Left</source>
        <translation>Alt+Kairėn</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1135"/>
        <source>Move &amp;Right</source>
        <translation>Perkelti d&amp;ešinėn</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1138"/>
        <source>Alt+Right</source>
        <translation>Alt+Dešinėn</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1146"/>
        <source>h&amp;2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1149"/>
        <source>Header 2</source>
        <translation>Antraštė 2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1152"/>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1160"/>
        <source>h&amp;1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1163"/>
        <source>Header 1</source>
        <translation>Antraštė 1</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1166"/>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1174"/>
        <source>h&amp;3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1177"/>
        <source>Header 3</source>
        <translation>Antraštė 3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1180"/>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1188"/>
        <source>&amp;Node Font</source>
        <translation>&amp;Mazgo šriftas</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1191"/>
        <source>Node Font</source>
        <translation>Mazgo šriftas</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1196"/>
        <source>Scale I&amp;mage(s)</source>
        <translation>Keisti pa&amp;veikslo(-ų) mastelį</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1204"/>
        <source>Paste &amp;HTML</source>
        <translation>Įdėti &amp;HTML</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1207"/>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1215"/>
        <source>&amp;Tags</source>
        <translation>Ž&amp;ymės</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1218"/>
        <source>Ctrl+Shift+T</source>
        <translation>Ctrl+Shift+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1226"/>
        <source>Insert Lin&amp;k</source>
        <translation>Įterpti nuoro&amp;dą</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1229"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1234"/>
        <source>C&amp;opy Link</source>
        <translation>K&amp;opijuoti nuorodą</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1242"/>
        <source>I&amp;nsert Table</source>
        <translation>Į&amp;terpti lentelę</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1245"/>
        <source>Ctrl+Alt+Shift+T</source>
        <translation>Ctrl+Alt+Shift+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1250"/>
        <source>Append Row</source>
        <translation>Pridėti eilutę apačioje</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1255"/>
        <source>Delete Row</source>
        <translation>Ištrinti eilutę</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1260"/>
        <source>Append Column</source>
        <translation>Pridėti stulpelį dešinėje</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1265"/>
        <source>Delete Column</source>
        <translation>Ištrinti stulpelį</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1270"/>
        <source>Merge Cells</source>
        <translation>Sulieti langelius</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1275"/>
        <source>Prepend Row</source>
        <translation>Pridėti eilutę aukščiau</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1280"/>
        <source>Prepend Column</source>
        <translation>Pridėti stulpelį kairėje</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1288"/>
        <source>Export &amp;HTML</source>
        <translation>Eksportuoti &amp;HTML</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1293"/>
        <source>Save Ima&amp;ge(s)</source>
        <translation>Įrašyti paveiks&amp;lą(-us)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1304"/>
        <source>RTL</source>
        <translation>Iš dešinės į kairę</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1307"/>
        <source>Ctrl+Alt+Shift+Left</source>
        <translation>Ctrl+Alt+Shift+Kairėn</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1318"/>
        <source>LTR</source>
        <translation>Iš kairės į dešinę</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1321"/>
        <source>Ctrl+Alt+Shift+Right</source>
        <translation>Ctrl+Alt+Shift+Dešinėn</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1326"/>
        <location filename="../../fn.ui" line="1329"/>
        <source>Menu</source>
        <translation>Meniu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1337"/>
        <source>Node &amp;Icon</source>
        <translation>Mazgo p&amp;iktograma</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1340"/>
        <source>Ctrl+Shift+C</source>
        <translation>Ctrl+Shift+C</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1345"/>
        <location filename="../../fn.ui" line="1348"/>
        <source>Check Spelling</source>
        <translation>Tikrinti rašybą</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1351"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1356"/>
        <source>Document &amp;Colors</source>
        <translation>Dokumentų &amp;spalvos</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1364"/>
        <location filename="../../fn.ui" line="1367"/>
        <source>Paste Date and Time</source>
        <translation>Įdėti datą ir laiką</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1372"/>
        <source>&amp;Clear</source>
        <translation>&amp;Išvalyti</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2963"/>
        <source>Node Icon</source>
        <translation>Mazgo piktograma</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="675"/>
        <source>&amp;Raise/Hide</source>
        <translation>&amp;Iškelti/Slėpti</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="927"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;New note?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Nauji užrašai?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="928"/>
        <source>&lt;center&gt;&lt;i&gt;Do you really want to leave this document&lt;/i&gt;&lt;/center&gt;
&lt;center&gt;&lt;i&gt;and create an empty one?&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;Ar tikrai norite užverti šį dokumentą&lt;/i&gt;&lt;/center&gt;
&lt;center&gt;&lt;i&gt;ir sukurti tuščią?&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="931"/>
        <location filename="../../fn.cpp" line="2794"/>
        <location filename="../../fn.cpp" line="4741"/>
        <source>Yes</source>
        <translation>Taip</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="932"/>
        <location filename="../../fn.cpp" line="2795"/>
        <location filename="../../fn.cpp" line="4742"/>
        <source>No</source>
        <translation>Ne</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1023"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Save changes?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Įrašyti pakeitimus?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1025"/>
        <source>&lt;center&gt;&lt;i&gt;The document has been modified.&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;Dokumentas buvo modifikuotas.&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1027"/>
        <source>&lt;center&gt;&lt;i&gt;The document has been removed.&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;Dokumentas pašalintas.&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1032"/>
        <source>Discard changes</source>
        <translation>Atmesti pakeitimus</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1033"/>
        <location filename="../../fn.cpp" line="2912"/>
        <location filename="../../fn.cpp" line="3006"/>
        <location filename="../../fn.cpp" line="3279"/>
        <location filename="../../fn.cpp" line="4317"/>
        <location filename="../../fn.cpp" line="4402"/>
        <location filename="../../fn.cpp" line="4580"/>
        <location filename="../../fn.cpp" line="4843"/>
        <location filename="../../fn.cpp" line="5796"/>
        <location filename="../../fn.cpp" line="6075"/>
        <location filename="../../fn.cpp" line="6173"/>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1443"/>
        <source>Open file...</source>
        <translation>Atverti failą...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1620"/>
        <location filename="../../fn.cpp" line="5922"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Cannot be saved!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Nepavyksta įrašyti!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3575"/>
        <source>Close</source>
        <translation>Užverti</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1720"/>
        <location filename="../../fn.cpp" line="1743"/>
        <source>Save As...</source>
        <translation>Įrašyti kaip...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1445"/>
        <location filename="../../fn.cpp" line="1722"/>
        <location filename="../../fn.cpp" line="1745"/>
        <source>FeatherNotes documents</source>
        <translation>FeatherNotes dokumentai</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1445"/>
        <location filename="../../fn.cpp" line="1722"/>
        <location filename="../../fn.cpp" line="1745"/>
        <location filename="../../fn.cpp" line="2995"/>
        <location filename="../../fn.cpp" line="4501"/>
        <location filename="../../fn.cpp" line="4772"/>
        <source>All Files</source>
        <translation>Visi failai</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2791"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Delete this node?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Ištrinti šį mazgą?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2792"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;i&gt;Warning!&lt;/i&gt;&lt;/b&gt;&lt;/center&gt;
&lt;center&gt;This action cannot be undone.&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;i&gt;Įspėjimas!&lt;/i&gt;&lt;/b&gt;&lt;/center&gt;
&lt;center&gt;Šio veiksmo neįmanoma bus atšaukti.&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2898"/>
        <source>Tags</source>
        <translation>Žymės</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2913"/>
        <location filename="../../fn.cpp" line="3007"/>
        <location filename="../../fn.cpp" line="3280"/>
        <location filename="../../fn.cpp" line="4319"/>
        <location filename="../../fn.cpp" line="4403"/>
        <location filename="../../fn.cpp" line="4581"/>
        <location filename="../../fn.cpp" line="4844"/>
        <location filename="../../fn.cpp" line="5798"/>
        <location filename="../../fn.cpp" line="6076"/>
        <location filename="../../fn.cpp" line="6174"/>
        <source>OK</source>
        <translation>Gerai</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2995"/>
        <location filename="../../fn.cpp" line="4501"/>
        <location filename="../../fn.cpp" line="4772"/>
        <source>Image Files</source>
        <translation>Paveikslo failai</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3087"/>
        <location filename="../../fn.cpp" line="3120"/>
        <source>&lt;b&gt;Main nodes:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;All nodes:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;</source>
        <translation>&lt;b&gt;Pagrindinių mazgų:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;Viso mazgų:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3093"/>
        <location filename="../../fn.cpp" line="3126"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&lt;br&gt;&lt;b&gt;Main nodes:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;All nodes:&lt;/b&gt; &lt;i&gt;%3&lt;/i&gt;</source>
        <translation>&lt;b&gt;Užrašai:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&lt;br&gt;&lt;b&gt;Pagrindinių mazgų:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;Viso mazgų:&lt;/b&gt; &lt;i&gt;%3&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3562"/>
        <source>%1 Matches</source>
        <translation>%1 atitikmenys(-ų)</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3564"/>
        <source>One Match</source>
        <translation>Vienas atitikmuo</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3566"/>
        <location filename="../../fn.cpp" line="3933"/>
        <source>No Match</source>
        <translation>Atitikmenų nėra</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3732"/>
        <location filename="../../fn.cpp" line="3785"/>
        <source>Replacement</source>
        <translation>Pakeitimas</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4040"/>
        <source>No Replacement</source>
        <translation>Jokių pakeitimų</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4042"/>
        <source>One Replacement</source>
        <translation>Vienas pakeitimas</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4045"/>
        <source>%1 Replacements</source>
        <translation>%1 pakeitimų(-ai)</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4305"/>
        <source>Insert Link</source>
        <translation>Įterpti nuorodą</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6019"/>
        <source>HTML Files</source>
        <translation>HTML failai</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2971"/>
        <location filename="../../fn.cpp" line="4387"/>
        <source>Image path</source>
        <translation>Paveikslo kelias</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2975"/>
        <location filename="../../fn.cpp" line="4391"/>
        <source>Open image</source>
        <translation>Atverti paveikslą</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4399"/>
        <location filename="../../fn.cpp" line="4577"/>
        <source>Scaling percentage</source>
        <translation>Mastelio keitimo procentinė dalis</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2993"/>
        <location filename="../../fn.cpp" line="4499"/>
        <source>Open Image...</source>
        <translation>Atverti paveikslą...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="652"/>
        <source>System tray is not available.
Please disable tray in Preferences.</source>
        <translation>Sistemos dėklas yra neprieinamas.
Išjunkite nuostatose dėklą.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="978"/>
        <source>New Node</source>
        <translation>Naujas mazgas</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1621"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Cannot be opened!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Nepavyksta atverti!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1702"/>
        <location filename="../../fn.cpp" line="5637"/>
        <location filename="../../fn.cpp" line="5646"/>
        <location filename="../../fn.cpp" line="5785"/>
        <location filename="../../fn.cpp" line="5976"/>
        <location filename="../../fn.cpp" line="5985"/>
        <location filename="../../fn.cpp" line="6012"/>
        <source>Untitled</source>
        <translation>Be pavadinimo</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2169"/>
        <source>Align Table</source>
        <translation>Lygiuoti lentelę</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2182"/>
        <source>&amp;Center</source>
        <translation>&amp;Centre</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2621"/>
        <source>Select Text Color</source>
        <translation>Pasirinkti teksto spalvą</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2653"/>
        <source>Select Background Color</source>
        <translation>Pasirinkti fono spalvą</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2790"/>
        <source>Deletion</source>
        <translation>Ištrynimas</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2908"/>
        <source>Tag(s) for this node</source>
        <translation>Šio mazgo žymė(-s)</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3164"/>
        <source>Select Document Font</source>
        <translation>Pasirinkti dokumento šriftą</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3226"/>
        <source>Select Node Font</source>
        <translation>Pasirinkti mazgo šriftą</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3251"/>
        <source>Set Document Colors</source>
        <translation>Nustatyti dokumentų spalvą</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3261"/>
        <source>These colors will be applied to new nodes.&lt;br&gt;They may or may not affect existing nodes&lt;br&gt;but document reopening is recommended.</source>
        <translation>Šios spalvos bus taikomos naujiems mazgams.&lt;br&gt;Jos gali paveikti arba nepaveikti esamų mazgų,&lt;br&gt;tačiau rekomenduojama atverti dokumentus iš naujo.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3264"/>
        <source>Background color:</source>
        <translation>Fono spalva:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3270"/>
        <source>Text color:</source>
        <translation>Teksto spalva:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4050"/>
        <source>The first 1000 replacements are highlighted.</source>
        <translation>Yra paryškinti pirmieji 1000 pakeitimų.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4394"/>
        <location filename="../../fn.cpp" line="4573"/>
        <source>Scale to</source>
        <translation>Keisti mastelį į</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4398"/>
        <location filename="../../fn.cpp" line="4576"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4567"/>
        <source>Scale Image(s)</source>
        <translation>Keisti paveikslo(-ų) mastelį</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4704"/>
        <source>untitled</source>
        <translation>be pavadinimo</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4736"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4737"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Image cannot be saved! Retry?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Nepavyksta įrašyti paveikslo! Bandyti dar kartą?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4738"/>
        <source>&lt;center&gt;Maybe you did not choose a proper extension&lt;/center&gt;
&lt;center&gt;or do not have write permission.&lt;/center&gt;&lt;p&gt;&lt;/p&gt;</source>
        <translation>&lt;center&gt;Galbūt, nepasirinkote tinkamo prievardžio&lt;/center&gt;
&lt;center&gt;arba neturite leidimų rašyti.&lt;/center&gt;&lt;p&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4770"/>
        <source>Save Image As...</source>
        <translation>Įrašyti paveikslą kaip...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4825"/>
        <source>Insert Table</source>
        <translation>Įterpti lentelę</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4831"/>
        <source>Rows:</source>
        <translation>Eilučių:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4837"/>
        <source>Columns:</source>
        <translation>Stulpelių:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5726"/>
        <source>Print Document</source>
        <translation>Spausdinti dokumentą</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5732"/>
        <source>Printing completed.</source>
        <translation>Spausdinimas užbaigtas.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5734"/>
        <source>Printing in progress...</source>
        <translation>Vyksta spausdinimas...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5753"/>
        <source>Export HTML</source>
        <translation>Eksportuoti HTML</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5758"/>
        <source>Export:</source>
        <translation>Eksportuoti:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5759"/>
        <source>&amp;Current node</source>
        <translation>&amp;Esamą mazgą</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5761"/>
        <source>With all &amp;sub-nodes</source>
        <translation>Su visais &amp;pomazgiais</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5762"/>
        <source>&amp;All nodes</source>
        <translation>&amp;Visus mazgus</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5774"/>
        <source>Output file:</source>
        <translation>Išvesties failas:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5793"/>
        <source>Select path</source>
        <translation>Pasirinkti kelią</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5834"/>
        <source>Question</source>
        <translation>Klausimas</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5835"/>
        <source>The file already exists.
Do you want to replace it?
</source>
        <translation>Failas jau yra.
Ar norite jį pakeisti?
</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6017"/>
        <source>Save HTML As...</source>
        <translation>Įrašyti HTML kaip...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6043"/>
        <source>Set Password</source>
        <translation>Nustatyti slaptažodį</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6052"/>
        <source>Type password</source>
        <translation>Įrašykite slaptažodį</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6064"/>
        <source>Retype password</source>
        <translation>Pakartokite slaptažodį</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6136"/>
        <source>&lt;center&gt;Passwords were different. Retry!&lt;/center&gt;</source>
        <translation>&lt;center&gt;Slaptažodžiai buvo skirtingi. Bandykite dar kartą!&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6156"/>
        <location filename="../../fn.cpp" line="6164"/>
        <source>Enter Password</source>
        <translation>Įveskite slaptažodį</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6236"/>
        <source>&lt;center&gt;Wrong password. Retry!&lt;/center&gt;</source>
        <translation>&lt;center&gt;Neteisingas slaptažodis. Bandykite dar kartą!&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6275"/>
        <source>A lightweight notes manager</source>
        <translation>Supaprastinta užrašų tvarkytuvė</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6276"/>
        <source>based on Qt</source>
        <translation>pagrįsta Qt</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6277"/>
        <source>Author</source>
        <translation>Autorius</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6279"/>
        <location filename="../../fn.cpp" line="6280"/>
        <source>About FeatherNotes</source>
        <translation>Apie FeatherNotes</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6279"/>
        <source>Translators</source>
        <translation>Vertėjai</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6463"/>
        <source>See Preferences → Text → Spell Checking!</source>
        <translation>Žiūrėkite Nuostatos → Tekstas → Rašybos tikrinimas!</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6479"/>
        <source>You need to add a Hunspell dictionary.</source>
        <translation>Turite pridėti Hunspell žodyną.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6484"/>
        <source>The Hunspell dictionary does not exist.</source>
        <translation>Nėra Hunspell žodyno.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6492"/>
        <source>The Hunspell dictionary is not accompanied by an affix file.</source>
        <translation>Hunspell žodynas nėra lydimas pridedamo failo.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6510"/>
        <location filename="../../fn.cpp" line="6525"/>
        <location filename="../../fn.cpp" line="6537"/>
        <source>No misspelling from text cursor.</source>
        <translation>Pradedant nuo teksto žymeklio nėra rašymo su klaidomis.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6549"/>
        <source>Spell Checking</source>
        <translation>Rašybos tikrinimas</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6278"/>
        <source>aka.</source>
        <translation>dar žinomas kaip</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::LineEdit</name>
    <message>
        <location filename="../../lineedit.cpp" line="35"/>
        <source>Clear text (Ctrl+K)</source>
        <translation>Išvalyti tekstą (Ctrl+K)</translation>
    </message>
    <message>
        <location filename="../../lineedit.cpp" line="81"/>
        <source>Ctrl+K</source>
        <comment>Clear text</comment>
        <translation>Ctrl+K</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::PrefDialog</name>
    <message>
        <location filename="../../prefDialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Nuostatos</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="27"/>
        <source>Window</source>
        <translation>Langas</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="36"/>
        <source>Saves window size after closing
this dialog and also on exit.

Uncheck to set a fixed size!</source>
        <translation>Įrašo lango dydį užvėrus šį dialogą,
o taip pat išeinant iš programos.

Nuimkite žymėjimą, norėdami nustatyti
fiksuotą dydį!</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="42"/>
        <source>Remember window &amp;size</source>
        <translation>Prisiminti lango &amp;dydį</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="51"/>
        <source>Start with this size: </source>
        <translation>Pradėti šiuo dydžiu: </translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="58"/>
        <location filename="../../prefDialog.ui" line="72"/>
        <source> px</source>
        <translation> piks.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="97"/>
        <source>Saves tree width after closing
this dialog and also on exit.

Uncheck for a width ratio of 170/530.</source>
        <translation>Įrašo medžio plotį užvėrus šį dialogą,
o taip pat išeinant iš programos.

Nuimkite žymėjimą, norėdami palikti
pločio santykį 170/530.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="103"/>
        <source>Remember &amp;tree width</source>
        <translation>Prisiminti &amp;medžio plotį</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="110"/>
        <source>Saves position after closing
this dialog and also on exit.

This may not work correctly
with some window managers.</source>
        <translation>Įrašo poziciją užvėrus šį dialogą,
o taip pat išėjus.

Tai gali tinkamai neveikti su
kai kuriomis langų tvarkytuvėmis.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="117"/>
        <source>Save &amp;position</source>
        <translation>Įrašyti &amp;poziciją</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="124"/>
        <source>Decides whether a systray icon should be used.
If checked, the titlebar close button iconifies
the window to the systray instead of quitting.

Needs restarting of FeatherNotes to take effect.</source>
        <translation>Apsprendžia ar turėtų būti naudojama dėklo piktograma.
Jei pažymėta, užvėrus programą per pavadinimo juostoje esantį
užvėrimo mygtuką, iš jos nebus išeita, o jos langas bus suskleistas
į sistemos dėklo piktogramą.

Tam, kad įsigaliotų, reikalauja paleisti FeatherNotes iš naujo.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="131"/>
        <source>Add to s&amp;ystray</source>
        <translation>Pridėti į sis&amp;temos dėklą</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="156"/>
        <source>The command line option --tray
can be used instead of this.</source>
        <translation>Vietoj to, gali būti naudojama
komandų eilutės parinktis --tray.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="160"/>
        <source>Start i&amp;conified to tray</source>
        <translation>Paleisti &amp;suskleistą į dėklą</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="169"/>
        <source>Merge the tree view with its surroundings?</source>
        <translation>Sulieti medžių rodinį su jo aplinka?</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="172"/>
        <source>Transparent t&amp;ree view</source>
        <translation>Permatomas me&amp;džių rodinys</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="179"/>
        <source>By default, the active widget style determines
the size of toolbar icons.</source>
        <translation>Pagal numatymą, aktyvus valdiklių stilius nustato
įrankių juostos piktogramų dydį.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="183"/>
        <source>Small toolbar icons</source>
        <translation>Mažos įrankių juostos piktogramos</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="190"/>
        <source>Do not show t&amp;oolbar</source>
        <translation>Nerodyti į&amp;rankių juostos</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="197"/>
        <source>If the menubar is hidden,
a menu button appears on the toolbar.</source>
        <translation>Jei meniu juosta yra paslėpta,
įrankių juostoje atsiranda meniu mygtukas.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="201"/>
        <source>Do not show &amp;menubar</source>
        <translation>Nerodyti &amp;meniu juostos</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="228"/>
        <source>Text</source>
        <translation>Tekstas</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="237"/>
        <source>&amp;Wrap lines by default</source>
        <translation>Pagal numatymą, s&amp;kaidyti eilutes</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="244"/>
        <source>Auto-&amp;indent by default</source>
        <translation>Pagal numatymą, daryti automatinę į&amp;trauką</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="251"/>
        <source>This covers parentheses, braces, brackets and quotes.

Needs restarting of FeatherNotes to take effect.</source>
        <translation>Tai apima įvairius skliaustelius, riestinius skliaustus ir kabutes.

Tam, kad įsigaliotų, reikalauja paleisti FeatherNotes iš naujo.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="256"/>
        <source>Auto-&amp;bracket</source>
        <translation>Automatiniai skl&amp;iaustai</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="263"/>
        <source>A triple period is replaced with an ellipsis,
a double hyphen with a long dash, etc. while
the user is typing and under proper circumstances.</source>
        <translation>Naudotojui rašant, esant tinkamoms aplinkybėms,
trys taškai yra pakeičiami daugtaškiu, o dvigubas brūkšnelis
ilguoju brūkšniu ir t.t.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="268"/>
        <source>&amp;Replace some characters while typing</source>
        <translation>&amp;Rašant, pakeisti kai kuriuos simbolius</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="277"/>
        <location filename="../../prefDialog.ui" line="290"/>
        <source>Used for pasting the date and time.
Leave empty for the system default.

Takes effect after closing this dialog.</source>
        <translation>Naudojama datos ir laiko įdėjimui.
Palikite tuščią norėdami naudoti
sistemos numatytąsias reikšmes.

Įsigalios, kai užversite šį dialogą.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="283"/>
        <source>Date and time format:</source>
        <translation>Datos ir laiko formatas:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="307"/>
        <source>&amp;Auto-save every</source>
        <translation>&amp;Automatiškai įrašyti kas</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="314"/>
        <source> minute(s)</source>
        <translation> minutes(-ių)</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="348"/>
        <source>If this option is checked, the opened document will
be saved on exiting without prompt and without
showing a warning if saving is not possible.</source>
        <translation>Jei ši parinktis pažymėta, išeinant iš programos, atvertas dokumentas bus
įrašytas be jokio paklausimo, o jei įrašymas yra neįmanomas,
nebus rodoma jokio įspėjimo.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="353"/>
        <source>Save opened document on exiting</source>
        <translation>Išeinant iš programos įrašyti atvertą dokumentą</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="376"/>
        <source>Spell Checking</source>
        <translation>Rašybos tikrinimas</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="384"/>
        <location filename="../../prefDialog.ui" line="396"/>
        <source>A Hunspell dictionary has a name that ends with &quot;.dic&quot;
and should be alongside an affix file with the same
name but ending with &quot;.aff&quot;.</source>
        <translation>Hunspell žodynas turi pavadinimą su prievardžiu „.dic“
ir turėtų būti kartu su pridedamu tokio pačio pavadinimo failu,
tačiau turinčiu „.aff“ prievardį.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="389"/>
        <source>Hunspell dictionary path:</source>
        <translation>Hunspell žodyno kelias:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="408"/>
        <location filename="../../pref.cpp" line="653"/>
        <source>Add dictionary...</source>
        <translation>Pridėti žodyną...</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="443"/>
        <source>Files</source>
        <translation>Failai</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="452"/>
        <source>Start with the last opened file</source>
        <translation>Paleidus programą, rodyti paskiausiai atvertą failą</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="464"/>
        <source>Number of recent files:</source>
        <translation>Paskiausių failų skaičius:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="496"/>
        <source>Open recent files separately</source>
        <translation>Atverti paskiausius failus atskirai</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="503"/>
        <source>By default, all nodes are expanded on opening a document.</source>
        <translation>Pagal numatymą, atveriant dokumentą visi mazgai yra išskleidžiami.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="506"/>
        <source>Remember expanded states of nodes</source>
        <translation>Prisiminti išskleistas mazgų būsenas</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="530"/>
        <source>Shortcuts</source>
        <translation>Spartieji klavišai</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="549"/>
        <source>Action</source>
        <translation>Veiksmas</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="554"/>
        <source>Shortcut</source>
        <translation>Spartusis klavišas</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="562"/>
        <source>Default</source>
        <translation>Numatytieji</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="346"/>
        <location filename="../../pref.cpp" line="526"/>
        <source>Warning: Ambiguous shortcut detected!</source>
        <translation>Įspėjimas: Aptiktas dviprasmiškas spartusis klavišas!</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="509"/>
        <source>The typed shortcut was reserved.</source>
        <translation>Įrašytas spartusis klavišas buvo rezervuotas.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="624"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation>Tam, kad įsigaliotų pakeitimai, reikia paleisti programą iš naujo.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="655"/>
        <source>Hunspell Dictionary Files</source>
        <translation>Hunspell žodyno failai</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::SpellDialog</name>
    <message>
        <location filename="../../spellDialog.ui" line="25"/>
        <source>Unknown word:</source>
        <translation>Nežinomas žodis:</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="51"/>
        <source>Add To Dictionary</source>
        <translation>Pridėti į žodyną</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="62"/>
        <source>Replace with:</source>
        <translation>Kuo pakeisti:</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="87"/>
        <source>Ignore Once</source>
        <translation>Nepaisyti vieną kartą</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="100"/>
        <source>Ignore All</source>
        <translation>Nepaisyti visų</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="129"/>
        <source>Correct Once</source>
        <translation>Ištaisyti vieną kartą</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="142"/>
        <source>Correct All</source>
        <translation>Ištaisyti visus</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::helpDialog</name>
    <message>
        <location filename="../../helpDialog.ui" line="14"/>
        <source>Help</source>
        <translation>Žinynas</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../domitem.cpp" line="101"/>
        <location filename="../../domitem.cpp" line="103"/>
        <location filename="../../domitem.cpp" line="142"/>
        <location filename="../../domitem.cpp" line="144"/>
        <source>New Node</source>
        <translation>Naujas mazgas</translation>
    </message>
</context>
</TS>
